@@ -1,9 +1,11 @@
 /* 
  * chasen.h - header file for ChaSen library
+ *
+ * $Id: chasen.h,v 1.3 2001/02/24 06:17:22 kazuma-t Exp $
  */
 
-#ifndef _CHASEN_H
-#define _CHASEN_H
+#ifndef __CHASEN_H__
+#define __CHASEN_H__
 
 /* variables */
 extern int Cha_optind;
@@ -15,4 +17,4 @@ extern int chasen_sparse(char*, FILE*);
 extern char *chasen_fparse_tostr(FILE*);
 extern char *chasen_sparse_tostr(char*);
 
-#endif
+#endif /* __CHASEN_H__ */
