@@ -36,7 +36,7 @@
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  * Modified by: A.Kitauchi <akira-k@is.aist-nara.ac.jp>, Oct. 1996
- * $Id: parse.c,v 1.24 2001/03/15 21:25:48 masayu-a Exp $
+ * $Id: parse.c,v 1.24.4.1 2001/04/17 08:11:23 masayu-a Exp $
  */
 
 #include "chalib.h"
@@ -723,7 +723,7 @@ cha_parse_sentence(char *target, int target_len, int opt_nobk)
     /*
      * ʸ 
      */
-    set_mrph_end(&Cha_mrph[mrph_idx]);
+    set_mrph_end(&Cha_mrph[mrph_idx-1]);
     if (++mrph_idx % MRPH_NUM == 0 && malloc_mrph())
 	goto error_end;
 
