@@ -35,28 +35,24 @@
  * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- * $Id: patfile.c,v 1.10 2001/02/14 00:20:53 masayu-a Exp $
+ * $Id: patfile.c,v 1.15 2001/03/02 00:09:17 masayu-a Exp $
  */
 #include "config.h"
 #include <stdio.h>
-#ifndef _WIN32
-#include <unistd.h>
-#endif
-#include <fcntl.h>
-#include <stdlib.h>
 
 #include "chadic.h"
 #include "pat.h"
 
 pat_node *pat_malloc_node(void);
-static void pat_init_tree_top(pat_node*);
-static void pat_com_l(char*, pat_node*);
-static void pat_com_s(char*, pat_node*);
+static void pat_init_tree_top(pat_node *);
+static void pat_com_l(char *, pat_node *);
+static void pat_com_s(char *, pat_node *);
 
 /*
  * pat_open
  */
-pat_t *pat_open(char *textfile, char *patfile)
+pat_t *
+pat_open(char *textfile, char *patfile)
 {
     pat_t *pat;
     void *map;
@@ -73,30 +69,34 @@ pat_t *pat_open(char *textfile, char *patfile)
     return pat;
 }
 
-void pat_load(pat_t *pat, char *patfile)
+void
+pat_load(pat_t * pat, char *patfile)
 {
     pat_com_l(patfile, pat->root);
 }
 
-void pat_save(pat_t *pat, char *patfile)
+void
+pat_save(pat_t * pat, char *patfile)
 {
     pat_com_s(patfile, pat->root);
 }
 
-void pat_text_reopen(pat_t *pat, char *textfile)
+void
+pat_text_reopen(pat_t * pat, char *textfile)
 {
     void *map;
 
     cha_munmap_file(pat->_map, pat->_size);
     pat = cha_malloc(sizeof(pat_t));
     pat->_size = cha_mmap_file(textfile, &map);
-    pat->_map = map;    
+    pat->_map = map;
 }
 
 /*
  * subroutines for pat_load_anode()
  */
-pat_index_list *pat_malloc_index_list(void)
+pat_index_list *
+pat_malloc_index_list(void)
 {
     static int idx = 1024;
     static pat_index_list *ptr;
@@ -109,7 +109,8 @@ pat_index_list *pat_malloc_index_list(void)
     return ptr + idx++;
 }
 
-pat_node *pat_malloc_node(void)
+pat_node *
+pat_malloc_node(void)
 {
     static int idx = 1024;
     static pat_node *ptr;
@@ -122,46 +123,59 @@ pat_node *pat_malloc_node(void)
     return ptr + idx++;
 }
 
-static void dummy(FILE *fp)
+static void
+dummy(FILE * fp)
 {
-    fputc(0xff,fp);
-    fputc(0xff,fp);
-    fputc(0xff,fp);
-    fputc(0xff,fp);
+    fputc(0xff, fp);
+    fputc(0xff, fp);
+    fputc(0xff, fp);
+    fputc(0xff, fp);
 }
 
-/****************************************************
-* pat_load_anode --- ѥȥꥷڤ
-*  by û(keiji-y@is.aist-nara.ac.jp)
-*
-* ѥ᡼
-*   in --- ե
-*   p_ptr --- ΥΡɤǤä˥ǥåǼ
-*             ǤäȤϡΥݥ󥿤ϱλҤϤ롣
-*
-* 르ꥺ
-*   åӥåȤɤ߹顢鿷Ρɤ
-*     ʬڡʬڤν˺Ƶ
-*     ƵλϿäΥݥ󥿤
-*     Ƶλ p_ptr 򥤥ǥåγǼȤϤ
-*   ǥåɤ߹顢ϳ顢p_ptr->index ˳Ǽ
-*
-* 
-*   ǥåγǼ꤬Ȱ㤦äʤ
-*************************************************************************/
-static pat_node *pat_load_anode(pat_node *p_ptr, FILE *fp)
+/*
+ * pat_load_anode ---  ѥȥꥷڤ
+ *                     load patricia tree
+ *  by û(keiji-y@is.aist-nara.ac.jp)
+ *
+ * parameters:
+ *   p_ptr --- ΥΡɤǤä˥ǥåǼ
+ *             ǤäȤϡΥݥ󥿤ϱλҤϤ롣
+ *             when the node is the outside node, p_ptr is the index.
+ *             when the node is the inside node, 
+ *                              this pointer pass to right tree.
+ *   fp --- input file
+ *          
+ *
+ * Algorithm
+ *   åӥåȤɤ߹顢鿷Ρɤ
+ *     ʬڡʬڤν˺Ƶ
+ *     ƵλϿäΥݥ󥿤
+ *     Ƶλ p_ptr 򥤥ǥåγǼȤϤ
+ *   ǥåɤ߹顢ϳ顢p_ptr->index ˳Ǽ
+ *
+ *   When read `checkbit', it will be inside node.
+ *     So make a new node. 
+ *     And do recursion to left subtree and right subtree in this order.
+ *     When left subtree recursion, return pointer to this new node.
+ *     When right subtree recursion, return p_ptr which contains `index'.
+ *   When read `index', it will be outside node.
+ *     Put `index' to p_ptr->index.
+ *
+ * memo
+ *   ǥåγǼ꤬Ȱ㤦äʤ
+ *   Where contains `index' is different between original algorithm 
+ *   and this program.  But no problem.
+ */
+static pat_node *
+pat_load_anode(pat_node * p_ptr, FILE * fp)
 {
     unsigned char c;
-    pat_node *new_ptr; /* äΡ(==ΥΡ)ؤݥ */
+    pat_node *new_ptr;      /* pointer to new node (= this node) */
+                       
     long tmp_idx;
-    pat_index_list *new_l_ptr,*t_ptr=NULL;
+    pat_index_list *new_l_ptr, *t_ptr = NULL;
 
-#if 0
-    static int dbg;
-    if (!(++dbg%1000))printf("%d,",dbg);
-#endif
-
-    if ((c = fgetc(fp)) & 0x80) { /* դäѤνǥåɤ߹ */
+    if ((c = fgetc(fp)) & 0x80) { /* process leaves, read index */
 	while (c & 0x80) {
 	    tmp_idx = (c & 0x3f) << 24;
 	    tmp_idx |= fgetc(fp) << 16;
@@ -178,92 +192,103 @@ static pat_node *pat_load_anode(pat_node *p_ptr, FILE *fp)
 	    new_l_ptr->next = NULL;
 	    t_ptr = new_l_ptr;
 
-	    if (c & 0x40) break;
+	    if (c & 0x40)
+		break;
 	    c = fgetc(fp);
 	}
 
-	return (p_ptr);
-    } else { /* νƵ */
+	return p_ptr;
+    } else {   /* process of inside node (recursive) */
 	new_ptr = pat_malloc_node();
-	new_ptr->checkbit = ((c << 8) | fgetc(fp)) - 1; /* åӥå */
-#if 0
-	printf("#cb %d\n",new_ptr->checkbit);
-#endif
+	new_ptr->checkbit = ((c << 8) | fgetc(fp)) - 1;	 /* checkbit */
 	(new_ptr->il).index = -1;
 	new_ptr->left = pat_load_anode(new_ptr, fp);
 	new_ptr->right = pat_load_anode(p_ptr, fp);
-	return (new_ptr);
+	return new_ptr;
     }
 }
 
-/******************************************************
-* pat_com_l --- ڤΥ
-*  by û(keiji-y@is.aist-nara.ac.jp)
-*
-* ѥ᡼֤
-*   ʤ
-******************************************************/
-static void pat_com_l(char *fname_pat, pat_node *ptr)
+/*
+ * pat_com_l --- load tree
+ *               
+ *  by û(keiji-y@is.aist-nara.ac.jp)
+ */
+static void
+pat_com_l(char *fname_pat, pat_node * ptr)
 {
     FILE *fp;
 
-#if 0
-    fprintf(stderr, "# Loading pat-tree \"%s\" ... ",fname_pat);
-#endif
-
     if ((fp = fopen(fname_pat, "rb")) == NULL) {
-	fprintf(stderr, "can't open %s\n",fname_pat);
+	fprintf(stderr, "can't open %s\n", fname_pat);
 	exit(1);
     }
     ptr->right = pat_load_anode(ptr, fp);
     fclose(fp);
-#if 0
-    fprintf(stderr,"done.\n");
-#endif
 }
 
-/****************************************************
-* save_pat --- ѥȥꥷڥǡ򥻡 
-*  by û(keiji-y@is.aist-nara.ac.jp)
-*
-* ѥ᡼
-*   top_ptr --- ϥΡɤΰ(ݥ)
-*   out_to --- (stdoutե)
-* 
-* ֤
-*   ̵ѥȥꥷڥǡϡ
-*
-* ϥեޥå --- 8ӥåȤ˶ڤäƥХʥ
-*   ͥõϥåӥåȡϥǥå
-*   åӥå --- ŪˤΤޤ ( 0 ӥåȤ 0)
-*      -1 ΤȤΤ 1 ­
-*   ǥå ---  0 ӥåȤ 1 ˤ
-****************************************************/
-static void save_pat(pat_node *top_ptr, FILE *fp)
+/*
+ * save_pat --- ѥȥꥷڥǡ򥻡 
+ *              save patricia tree data
+ *  by û(keiji-y@is.aist-nara.ac.jp)
+ *
+ * parameters:
+ *   top_ptr --- ϥΡɤΰ(ݥ)
+ *               pointer to a node -- search starting point
+ *   fp --- (stdoutե)
+ *               output (stdout or FILE)
+ * 
+ * return:
+ *   none.
+ *   output patricia tree to `fp'
+ *
+ * ϥեޥå --- 8ӥåȤ˶ڤäƥХʥ
+ * output format --- segment to 8bit per unit 
+ *   ͥõϥåӥåȡϥǥå
+ *   åӥå --- ŪˤΤޤ ( 0 ӥåȤ 0)
+ *      -1 ΤȤΤ 1 ­
+ *   ǥå ---  0 ӥåȤ 1 ˤ
+ *   left most search:
+ *        if inside node, output `checkbit'
+ *        if outside node, output `index'
+ *     `checkbit': basically we use original bit
+ *                 0 bit will be `0'
+ *                 But when -1 bit, plus 1.
+ *     `index': 0 bit will be `1'
+ */
+static void
+save_pat(pat_node * top_ptr, FILE * fp)
 {
     pat_index_list *ptr;
 
-    /* νåӥåȤ */
-    fputc (((top_ptr->checkbit + 1)>> 8) & 0x7f, fp);
-    fputc ((top_ptr->checkbit + 1)& 0xff, fp);
+    /*
+     * νåӥåȤ
+     *   process inside node, output checkbit
+     */
+    fputc(((top_ptr->checkbit + 1) >> 8) & 0x7f, fp);
+    fputc((top_ptr->checkbit + 1) & 0xff, fp);
 
-    /*  Subtree νդäѤʤ饤ǥåϡ
-       դäѤǤʤкƵ*/
+    /*
+     *  Subtree νդäѤʤ饤ǥåϡ
+     * դäѤǤʤкƵ
+     *   process subtree,
+     *     if node is a leaf, output index
+     *     otherwise, do recursion
+     */
     if (top_ptr->checkbit < top_ptr->left->checkbit)
 	save_pat(top_ptr->left, fp);
     else {
 	ptr = &(top_ptr->left->il);
-	if (ptr->index < 0) 
+	if (ptr->index < 0)
 	    dummy(fp);
 	else {
 	    while (ptr != NULL) {
 		if (ptr->next == NULL)
-		    fputc (((ptr->index >> 24) & 0x3f) | 0xc0, fp);
+		    fputc(((ptr->index >> 24) & 0x3f) | 0xc0, fp);
 		else
-		    fputc (((ptr->index >> 24) & 0x3f) | 0x80, fp);
-		fputc ((ptr->index >> 16) & 0xff, fp);
-		fputc ((ptr->index >> 8) & 0xff, fp);
-		fputc ((ptr->index) & 0xff, fp);
+		    fputc(((ptr->index >> 24) & 0x3f) | 0x80, fp);
+		fputc((ptr->index >> 16) & 0xff, fp);
+		fputc((ptr->index >> 8) & 0xff, fp);
+		fputc((ptr->index) & 0xff, fp);
 		ptr = ptr->next;
 	    }
 	}
@@ -272,53 +297,54 @@ static void save_pat(pat_node *top_ptr, FILE *fp)
 	save_pat(top_ptr->right, fp);
     else {
 	ptr = &(top_ptr->right->il);
-	if (ptr->index < 0) dummy(fp);
+	if (ptr->index < 0)
+	    dummy(fp);
 	else {
 	    while (ptr != NULL) {
 		if (ptr->next == NULL)
-		    fputc (((ptr->index >> 24) & 0x3f) | 0xc0, fp);
+		    fputc(((ptr->index >> 24) & 0x3f) | 0xc0, fp);
 		else
-		    fputc (((ptr->index >> 24) & 0x3f) | 0x80, fp);
-		fputc ((ptr->index >> 16) & 0xff, fp);
-		fputc ((ptr->index >> 8) & 0xff, fp);
-		fputc ((ptr->index) & 0xff, fp);
+		    fputc(((ptr->index >> 24) & 0x3f) | 0x80, fp);
+		fputc((ptr->index >> 16) & 0xff, fp);
+		fputc((ptr->index >> 8) & 0xff, fp);
+		fputc((ptr->index) & 0xff, fp);
 		ptr = ptr->next;
 	    }
 	}
     }
 }
 
-/*****************************************************
-* pat_com_s --- ڤΥ 
-*  by û(keiji-y@is.aist-nara.ac.jp)
-*
-* ѥ᡼֤
-*   ʤ
-*****************************************************/
-static void pat_com_s(char *fname_pat, pat_node *ptr)
+/*
+ * pat_com_s --- save a patricia tree to file
+ *               
+ *  by û(keiji-y@is.aist-nara.ac.jp)
+ */
+static void
+pat_com_s(char *fname_pat, pat_node * ptr)
 {
     FILE *fp;
 
-    printf("Saving pat-tree \"%s\" ...\n",fname_pat);
+    printf("Saving pat-tree \"%s\" ...\n", fname_pat);
     fp = fopen(fname_pat, "w+b");
     if (fp == NULL) {
 	fprintf(stderr, "can't open %s\n", fname_pat);
 	exit(1);
-    }; 
-    save_pat(ptr->right, fp); /* ե */
+    };
+    save_pat(ptr->right, fp);	/* output to file */
     fclose(fp);
 }
 
-/******************************************************
-* pat_init_tree_top --- ѥȥꥷڤκν
-*
-* ѥ᡼
-*   ptr --- ڤκؤΥݥ
-******************************************************/
-static void pat_init_tree_top(pat_node *ptr)
+/*
+ * pat_init_tree_top --- initialize a root of patricia tree
+ *                       
+ * parameter:
+ *   ptr --- pointer to a root of patricia tree 
+ */
+static void
+pat_init_tree_top(pat_node * ptr)
 {
-    (ptr->il).index = -1; /* ǥåΥꥹ */
-    ptr->checkbit = -1;
-    ptr->right = ptr;
-    ptr->left = ptr;
+    (ptr->il).index = -1;	/* list of index is -1 */
+    ptr->checkbit = -1;         /* checkbit is -1 */
+    ptr->right = ptr;           /* right node point itself */
+    ptr->left = ptr;            /* left node point itself */
 }
